#
# 	Loren Williams, Georgia Tech
#	parallel b-sheet
# 	pymol script for parallel-beta-sheet 
## Header: General Commands ##

# delete all objects and reset pymol
reinitialize
# set the background color to white
bg_color white
# make the background transparent for ray trace 
set ray_opaque_background, 0
# set the ray trace mode
# normal color
set ray_trace_mode, 0
# normal color + black outline
#set ray_trace_mode,  1
# black outline only
#set ray_trace_mode,  2
# turn off shadows during ray trace
set ray_shadows, 0
# set the mouse mode for laptop.
config_mouse one_button
# run the python program for hydrogen bonding interactions.
# get ride of double bonds and skinny bonds to H
set stick_h_scale, 1
set valence, 0
## Header: End General Commands ##

fetch 1Q6O, barrel

create sheet, resi 82-138 and barrel and chain A
h_add
remove resn hoh

create ribbon_sheet, sheet
remove ribbon_sheet and not (name N+O+CA+C+CB+H02)

create surface_sheet, sheet
remove surface_sheet and name H* and not name H02

create stick_schains_sheet, (resi 82-138) and barrel and chain A

hide everything, ribbon_sheet
show cartoon, ribbon_sheet
cartoon_fancy_helices, 0

hide everything, surface_sheet
show surface, surface_sheet
set transparency=0.4, surface_sheet

hide everything, stick_schains_sheet
show stick, stick_schains_sheet
remove stick_schains_sheet and name H* and not name H02

create stick_strand_A, resi 82-88 and sheet
create stick_helix_AB, resi 88-108 and sheet
create stick_strand_B, resi 108-114 and sheet
create stick_helix_BC, resi 114-131 and sheet
create stick_strand_C, resi 131-136 and sheet

hide everything, stick_*
show stick, stick_* 


label ribbon_sheet and resi 85 and name CA, " Strand A"
label ribbon_sheet and resi 112 and name CA, " Strand B"
label ribbon_sheet and resi 132 and name C, " Strand C"
label ribbon_sheet and resi 102 and name CA, " Helix AB"
label ribbon_sheet and resi 118 and name CB, " Helix BC"

set label_color, wheat, ribbon_sheet
set label_outline_color, black, ribbon_sheet
set label_shadow_mode=2, ribbon_sheet
set label_size, 14.0, ribbon_sheet


color wheat, name C*
color blue, name N*
color red, name O*

color cyan, ribbon_sheet

color wheat, ribbon_sheet and resi 82-88
color lightpink, ribbon_sheet and resi 89-107
color palegreen, ribbon_sheet and resi 108-113
color paleyellow, ribbon_sheet and resi 114-131
color lightblue, ribbon_sheet and resi 132-138

color wheat, surface_sheet and resi 82-88
color lightpink, surface_sheet and resi 89-107
color palegreen, surface_sheet and resi 108-114
color paleyellow, surface_sheet and resi 113-130
color lightblue, surface_sheet and resi 131-138


show stick, stick_*
remove stick_strand_* and not (name N+O+CA+C+CB) 
remove stick_helix_* and not (name N+O+CA+C+CB) 
h_add stick_* and name N
alter (name H0*),name='H'


#------------------------------H Bonds------

dist hbond_NH_O, (name O,H and stick_strand_A), (name O,H and stick_strand_B), 2.4 
dist hbond_NH_O, (name O,H and stick_strand_B), (name O,H and stick_strand_C), 2.4
#dist hbond_NH_O, (name O and stick_helix_AB), (name H and stick_helix_AB), 2.45
#dist hbond_NH_O, (name O and stick_helix_BC), (name H and stick_helix_BC), 2.45

#mode=2

color black, hbond_NH_O
set label_size, -0.30, hbond_NH_O
set dash_width, 3.0
set dash_gap, 0.4
set label_position, (1.2,0,0), hbond_NH_O

#------------------------------phi/psi------torsion angles

dihedral phi_a,  resi 109 and name C and stick_strand_B, resi 110 and name N and stick_strand_B, resi 110 and name CA and stick_strand_B, resi 110 and name C and stick_strand_B

create phi_a_atoms,  (resi 109 and name C and stick_strand_B)+(resi 110 and name N and stick_strand_B)+(resi 110 and name CA and stick_strand_B)+(resi 110 and name C and stick_strand_B)

dihedral psi_a,  resi 110 and name N and stick_strand_B, resi 110 and name CA and stick_strand_B, resi 110 and name C and stick_strand_B, resi 111 and name N and stick_strand_B 

create psi_a_atoms,  (resi 110 and name N and stick_strand_B)+(resi 110 and name CA and stick_strand_B)+(resi 110 and name C and stick_strand_B)+(resi 111 and name N and stick_strand_B)
 
 
show stick, phi_a_atoms
set stick_radius, 0.10, phi_a_atoms
label phi_a_atoms, name
show spheres, phi_a_atoms
alter phi_a_atoms, vdw=0.25
alter phi_a_atoms and name N, vdw=0.35
rebuild

show stick, psi_a_atoms
set stick_radius, 0.10, psi_a_atoms
label psi_a_atoms, name
show spheres, psi_a_atoms
alter psi_a_atoms, vdw=0.25
alter psi_a_atoms and name ca, vdw=0.35
rebuild

set label_color, red, phi_a
set label_color, red, phi_a_atoms
color red, phi_a

set label_color, magenta, psi_a
set label_color, magenta, psi_a_atoms
color magenta, psi_a

set dihedral_size, 2.0, phi_a
set dihedral_size, 2.5, psi_a
set line_width, 10



#- Peptide Planes -----82-138-------------------------
python
import sys
sys.path.append('./files/')
from draw_plane_cgo import *

for i in range (83, 137):
	plnme = "plane" + str(i-137)
	st1= 'resi ' + str(i) + ' and name CA'
	st2= 'resi ' + str(i) + ' and name O'
	st3= 'resi ' + str(i+1) + ' and name H02'
	st4= 'resi ' + str(i+1) + ' and name CA'
	cmd.select("st1", st1)
	cmd.select("st2", st2)
	cmd.select("st3", st3)
	cmd.select("st4", st4)
	cstr = ''
	ccode = i%3
	if ccode == 1:
		cstr = "(255,0,255)"
	elif ccode == 2:
		cstr = "(255,255,0)"
	else:
		cstr = "(0,255,255)"

	draw_plane(plnme, "st1", "st2", "st3", "st4",cstr)
python end

delete st1
delete st2
delete st3
delete st4

#------------------------------- label atoms and change atom names
alter (name H02),name='H'
sort
label stick_strand_*, name
label helix_*, name
set label_size, -.15, stick_strand_*
set label_size, -.15, helix_*

delete barrel
delete sheet
disable all
enable ribbon_sheet

set_view (\
    -0.623724878,    0.756028414,    0.198444858,\
     0.703241348,    0.431968093,    0.564661801,\
     0.341178536,    0.491746485,   -0.801108003,\
     0.000387527,    0.000129534,  -77.385963440,\
    57.827812195,    4.340866089,   29.232330322,\
    58.150131226,   96.620140076,  -20.000000000 )
### cut above here and paste into script ###